pub struct NowSessionWindowRecEventMsg<'a> { /* private fields */ }Expand description
The NOW_SESSION_WINDOW_REC_EVENT_MSG message is sent by the server to notify of window recording events such as active window changes, title changes, or when no window is active.
NOW_PROTO: NOW_SESSION_WINDOW_REC_EVENT_MSG
Implementations
Sourceimpl<'a> NowSessionWindowRecEventMsg<'a>
impl<'a> NowSessionWindowRecEventMsg<'a>
pub fn active_window( timestamp: u64, process_id: u32, title: impl Into<Cow<'a, str>>, executable_path: impl Into<Cow<'a, str>>, ) -> EncodeResult<Self>
pub fn title_changed( timestamp: u64, title: impl Into<Cow<'a, str>>, ) -> EncodeResult<Self>
pub fn no_active_window(timestamp: u64) -> Self
pub fn timestamp(&self) -> u64
pub fn kind(&self) -> &WindowRecEventKind<'a>