pub struct NowSessionMsgBoxRspMsg<'a> { /* private fields */ }Expand description
The NOW_SESSION_MSGBOX_RSP_MSG is a message sent in response to NOW_SESSION_MSGBOX_REQ_MSG if the NOW_MSGBOX_FLAG_RESPONSE has been set, and contains the result from the message box dialog.
NOW_PROTO: NOW_SESSION_MSGBOX_RSP_MSG
Implementations
Sourceimpl<'a> NowSessionMsgBoxRspMsg<'a>
impl<'a> NowSessionMsgBoxRspMsg<'a>
pub fn new_success(request_id: u32, response: NowMsgBoxResponse) -> Self
pub fn new_error( request_id: u32, error: impl Into<NowStatusError>, ) -> EncodeResult<Self>
pub fn request_id(&self) -> u32
Sourcepub fn to_result(&self) -> Result<NowMsgBoxResponse, NowStatusError>
pub fn to_result(&self) -> Result<NowMsgBoxResponse, NowStatusError>
Get the response from the message box dialog. Returns (Err(_) if the request has failed).